@@ -14,6 +14,7 @@ Usage::
         CustomerGatewayAvailableWaiter,
         DescribeByoipCidrsPaginator,
         DescribeCapacityReservationsPaginator,
+        DescribeCarrierGatewaysPaginator,
         DescribeClassicLinkInstancesPaginator,
         DescribeClientVpnAuthorizationRulesPaginator,
         DescribeClientVpnConnectionsPaginator,
@@ -178,6 +179,7 @@ Usage::
 
     describe_byoip_cidrs_paginator: DescribeByoipCidrsPaginator = client.get_paginator("describe_byoip_cidrs")
     describe_capacity_reservations_paginator: DescribeCapacityReservationsPaginator = client.get_paginator("describe_capacity_reservations")
+    describe_carrier_gateways_paginator: DescribeCarrierGatewaysPaginator = client.get_paginator("describe_carrier_gateways")
     describe_classic_link_instances_paginator: DescribeClassicLinkInstancesPaginator = client.get_paginator("describe_classic_link_instances")
     describe_client_vpn_authorization_rules_paginator: DescribeClientVpnAuthorizationRulesPaginator = client.get_paginator("describe_client_vpn_authorization_rules")
     describe_client_vpn_connections_paginator: DescribeClientVpnConnectionsPaginator = client.get_paginator("describe_client_vpn_connections")
@@ -273,6 +275,7 @@ from mypy_boto3_ec2.client import EC2Client
 from mypy_boto3_ec2.paginator import (
     DescribeByoipCidrsPaginator,
     DescribeCapacityReservationsPaginator,
+    DescribeCarrierGatewaysPaginator,
     DescribeClassicLinkInstancesPaginator,
     DescribeClientVpnAuthorizationRulesPaginator,
     DescribeClientVpnConnectionsPaginator,
@@ -414,6 +417,7 @@ __all__ = (
     "CustomerGatewayAvailableWaiter",
     "DescribeByoipCidrsPaginator",
     "DescribeCapacityReservationsPaginator",
+    "DescribeCarrierGatewaysPaginator",
     "DescribeClassicLinkInstancesPaginator",
     "DescribeClientVpnAuthorizationRulesPaginator",
     "DescribeClientVpnConnectionsPaginator",
